using API.Controllers;
using AppContext.Entities;
using DbServices;
using FluentAssertions;
using Microsoft.AspNetCore.Mvc;
using Microsoft.Data.Sqlite;
using Microsoft.EntityFrameworkCore;
using Model;
using StubContext;
using Xunit.Abstractions;

namespace UnitTests;

public class UsersControllerTest
{
    private static UsersController GetUserController(int userId)
    {
        var connection = new SqliteConnection("Data Source=:memory:");
        connection.Open();
        var context = new StubAppContext(
            new DbContextOptionsBuilder<AppContext.AppContext>()
                .UseSqlite(connection)
                .Options
        );
        context.Database.EnsureCreated();
        var controller = new UsersController(
            new DbUserService(context),
            new DbTeamService(context),
            new DbTacticService(context),
            new ManualContextAccessor(userId)
        );
        
        return controller;
    }

    [Fact]
    public async void GetCurrentUserTest()
    {
        var controller = GetUserController(1);
        var result = await controller.GetUser();
        result.Should().BeEquivalentTo(new User(1, "maxime", "maxime@mail.com",
            UsersController.DefaultProfilePicture, true));
    }

    [Fact]
    public async void GetUserDataTest()
    {
        var controller = GetUserController(1);
        var result = await controller.GetUserData();
        result.Should().BeEquivalentTo(new UsersController.GetUserDataResponse([], []));
    }
    
    [Fact]
    public async Task ShareTacticTest()
    {
        var controller = GetUserController(1);
        var result = await controller.ShareTactic(new UsersController.ShareTacticToUserRequest(1, 2));
        result.Should().BeOfType<OkResult>();
    }
    
    [Fact]
    public async Task GetSharedTacticsToUserTest()
    {
        var controller = GetUserController(2);
        var result = await controller.GetSharedTacticsToUser(2);

        var okResult = result as OkObjectResult;
        var sharedTactics = okResult.Value as IEnumerable<Tactic>;
        
        sharedTactics.Should().NotBeNull();
        sharedTactics.Should().ContainSingle();

        var tactic = sharedTactics.First();
        tactic.Id.Should().Be(1);
    }

    [Fact]
    public async Task UnshareTacticTest()
    {
        var controller = GetUserController(1);
        var result = await controller.UnshareTactic(1, 2);
        result.Should().BeOfType<OkResult>();
    }

}